@@ -13,15 +13,26 @@ use Carp;
 use English qw/ -no_match_vars /;
 use File::chdir;
 use Data::Dumper qw/Dumper/;
+use App::VTide::Sessions;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.1.21');
+our $VERSION = version->new('1.0.1');
 our $NAME    = 'edit';
-our $OPTIONS = [ 'recurse|r!', 'test|T!', 'save|s=s', 'verbose|v+', ];
-our $LOCAL   = 1;
+our $OPTIONS =
+  [ 'add|add-to-session|a', 'recurse|r!', 'test|T!', 'save|s=s', 'verbose|v+',
+  ];
+our $LOCAL = 1;
 sub details_sub { return ( $NAME, $OPTIONS, $LOCAL ) }
 
+has sessions => (
+    is      => 'ro',
+    lazy    => 1,
+    default => sub {
+        App::VTide::Sessions->new();
+    },
+);
+
 sub run {
     my ($self) = @_;
 
@@ -29,6 +40,10 @@ sub run {
     my $cmd = $self->options->files->[0];
     print "Running $name - $cmd\n";
 
+    if ( $self->defaults->{add} ) {
+        $self->sessions->add_session( @{ $self->options->files } );
+    }
+
     my $params = $self->params($cmd);
     $params->{edit}  = $self->options->files;
     $params->{title} = $cmd;
@@ -101,7 +116,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 0.1.21
+This documentation refers to App::VTide::Command::Edit version 1.0.1
 
 =head1 SYNOPSIS
 
